# checkfor.ai Python

### Usage
Install checkforai
```
pip install checkforai
```

Make a request
```
from checkforai import TextClassifier
classifier = TextClassifier()
result = classifier.predict(text)
```

Questions? Email me at max@checkfor.ai!
